<?php
namespace ovabrw_product_elementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Schemes\Typography;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Color;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class ovabrw_product_images extends Widget_Base {


	public function get_name() {		
		return 'ovabrw_product_images';
	}

	public function get_title() {
		return esc_html__( 'Product Images', 'ova-brw' );
	}

	public function get_icon() {
		return 'eicon-product-images';
	}

	public function get_categories() {
		return [ 'ovatheme' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'section_product_gallery_style',
			[
				'label' => esc_html__( 'Style', 'ova-brw' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'wc_style_warning',
				[
					'type' 	=> Controls_Manager::RAW_HTML,
					'raw' 	=> esc_html__( 'The style of this widget is often affected by your theme and <p></p>lugins. If you experience any such issue, try to switch to a basic theme and deactivate related plugins.', 'ova-brw' ),
					'content_classes' => 'elementor-panel-alert elementor-panel-alert-info',
				]
			);

			$this->add_responsive_control(
				'image_border_radius',
				[
					'label' 	 => esc_html__( 'Border Radius', 'ova-brw' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%' ],
					'selectors'  => [
						'.woocommerce {{WRAPPER}} .ova-product-img .item-img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
					],
				]
			);

			$this->add_responsive_control(
				'spacing',
				[
					'label' 	 => esc_html__( 'Spacing Image', 'ova-brw' ),
					'type' 		 => Controls_Manager::SLIDER,
					'size_units' => [ 'px', 'em' ],
					'selectors'  => [
						'.woocommerce {{WRAPPER}} .ova-product-img .list-img' => 'grid-gap: {{SIZE}}{{UNIT}}',
					],
				]
			);

		$this->end_controls_section();
	}

	protected function render() {

		$settings = $this->get_settings();

		global $product;

		$product = wc_get_product();

		if ( empty( $product ) ) {
			?>
			<div class="ovabrw_elementor_no_product">
				<span><?php echo $this->get_title(); ?></span>
			</div>
			<?php
			return;
		}

		$product_id = $product->get_id();
		$img_url 	= $img_alt = '';
		$img_id 	= $product->get_image_id();

		if ( $img_id ) {
			$img_url = wp_get_attachment_url( $img_id );
			$img_alt = get_post_meta( $img_id, '_wp_attachment_image_alt', true );

			if ( ! $img_alt ) {
				$img_alt = get_the_title( $img_id );
			}
		}

		$gallery_ids 	= $product->get_gallery_image_ids();

		?>
		<?php if ( $img_url ): ?>
			<div class="ova-product-img">
				<ul class="list-img">
					<li class="item-img featured-img">
						<a class="gallery-fancybox" 
							data-src="<?php echo esc_url( $img_url ); ?>" 
							data-fancybox="ova_product_img_group" 
							data-caption="<?php echo esc_attr( $img_alt ); ?>">
		  					<img src="<?php echo esc_url( $img_url ); ?>" alt="<?php echo esc_attr( $img_alt ); ?>">
		  				</a>
					</li>
					<?php if ( $gallery_ids ): ?>
						<?php foreach( $gallery_ids as $k => $gallery_id ):
							$gallery_url = wp_get_attachment_url( $gallery_id );
							$gallery_alt = get_post_meta( $gallery_id, '_wp_attachment_image_alt', true );

							if ( ! $gallery_alt ) {
								$gallery_alt = get_the_title( $gallery_id );
							}

							$hidden = ( $k > 3 ) ? ' gallery_hidden' : '';
							$blur 	= ( $k == 3 && count( $gallery_ids ) > 4 ) ? ' gallery_blur' : '';

						?>
							<li class="item-img<?php printf( $hidden ); ?><?php printf( $blur ); ?>">
								<a class="gallery-fancybox" 
									data-src="<?php echo esc_url( $gallery_url ); ?>" 
									data-fancybox="ova_product_img_group" 
									data-caption="<?php echo esc_attr( $gallery_alt ); ?>">
				  					<img src="<?php echo esc_url( $gallery_url ); ?>" alt="<?php echo esc_attr( $gallery_alt ); ?>">
				  					<?php if ( $blur ): ?>
				  						<div class="blur-bg">
				  							<span class="gallery-count">
				  								<?php echo esc_html( '+', 'ova-brw' ) . esc_html( count( $gallery_ids ) - 4 ); ?>
				  							</span>
				  						</div>
				  					<?php endif; ?>
				  				</a>
							</li>
						<?php endforeach; ?>
					<?php endif; ?>
				</ul>
			</div>
		<?php endif; ?>
		<?php	
	}
}