<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Box_Shadow;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class hotelft_Elementor_Awards extends Widget_Base {

	
	public function get_name() {
		return 'hotelft_elementor_awards';
	}

	
	public function get_title() {
		return esc_html__( 'Awards', 'hotelft' );
	}

	
	public function get_icon() {
		return 'eicon-image-box';
	}

	
	public function get_categories() {
		return [ 'hotelft' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'hotelft' ),
			]
		);	
			
			// Add Class control
			 $this->add_control(
				'image',
				[
					'label' => esc_html__( 'Image', 'hotelft' ),
					'type' => Controls_Manager::MEDIA,
					'dynamic' => [
						'active' => true,
					],
					'default' => [
						'url' => Utils::get_placeholder_image_src(),
					],
					'separator' => 'before'
				]
			);
				
			$this->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'hotelft' ),
					'type' => Controls_Manager::TEXT,
					'default' => esc_html__( 'Top choice', 'hotelft' ),
				]
			);

			$this->add_control(
				'link_title',
				[
					'label' => esc_html__( 'Link Title', 'hotelft' ),
					'type' => Controls_Manager::URL,
					
					'dynamic' => [
						'active' => true,
					],
					'placeholder' => esc_html__( 'https://your-link.com', 'hotelft' ),
				]
			);

			$this->add_control(
				'description',
				[
					'label' => esc_html__( 'Description', 'hotelft' ),
					'type' => Controls_Manager::TEXTAREA,
					'default' => esc_html__( 'The Award was presented by the national hospitality association in 1998.', 'hotelft' ),
				]
			);

		$this->end_controls_section();

		/* Begin title Style */
		$this->start_controls_section(
            'title_style',
            [
                'label' => esc_html__( 'Title', 'hotelft' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'title_typography',
					'selector' 	=> '{{WRAPPER}} .ova-awards .info .title',
				]
			);

			$this->add_control(
				'title_color',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-awards .info .title, {{WRAPPER}} .ova-awards .info .title a' => 'color : {{VALUE}};'
					],
				]
			);

			$this->add_control(
				'title_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-awards:hover .info .title, {{WRAPPER}} .ova-awards:hover .info .title a' => 'color : {{VALUE}};'
					],
				]
			);

			$this->add_responsive_control(
	            'title_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-awards .info .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End title style */

		/* Begin description Style */
		$this->start_controls_section(
            'description_style',
            [
                'label' => esc_html__( 'Description', 'hotelft' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'description_typography',
					'selector' 	=> '{{WRAPPER}} .ova-awards .info .description',
				]
			);

			$this->add_control(
				'description_color',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-awards .info .description' => 'color : {{VALUE}};'
					],
				]
			);

			$this->add_responsive_control(
	            'description_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-awards .info .description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End description style */

		/* Begin image style */
		$this->start_controls_section(
			'section_image_style',
			[
				'label' => esc_html__( 'Image', 'hotelft' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_responsive_control(
				'image_max_width',
				[
					'label' 	=> esc_html__( 'Max Width', 'hotelft' ),
					'type' 		=> Controls_Manager::SLIDER,
					'default' 	=> [
						'unit' 	=> 'px',
					],
					'tablet_default' => [
						'unit' => 'px',
					],
					'mobile_default' => [
						'unit' => 'px',
					],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ '%', 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-awards .img .awards-img' => 'max-width: {{SIZE}}{{UNIT}}',
					],
				]
			);

		$this->end_controls_section();
		/* End image style */

		// Awards style Tab
		$this->start_controls_section(
			'section_style_awards',
			[
				'label' => esc_html__( 'Awards', 'hotelft' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->start_controls_tabs( 'Style Awards' );

		$this->start_controls_tab(
			'awards_normal',
			[
				'label' => esc_html__( 'Normal', 'hotelft' ),
			]
		);

			$this->add_control(
				'bgcolor',
				[
					'label' => esc_html__( 'Background', 'hotelft' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-awards' => 'background-color : {{VALUE}};'
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'box_shadow_awards',
					'label' => __( 'Box Shadow', 'hotelft' ),
					'selector' => '{{WRAPPER}} .ova-awards',
				]
		    );

		    $this->add_responsive_control(
	            'awards_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-awards' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );
			
		$this->end_controls_tab();

		$this->start_controls_tab(
			'awards_hover',
			[
				'label' => esc_html__( 'Hover', 'hotelft' ),
			]
		);
				
			
			$this->add_control(
				'bgcolor_hover',
				[
					'label' => esc_html__( 'Background', 'hotelft' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-awards:hover' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'box_shadow_awards_hover',
					'label' => __( 'Box Shadow', 'hotelft' ),
					'selector' => '{{WRAPPER}} .ova-awards:hover',
				]
		    );

		$this->end_controls_tab();

	    $this->end_controls_tabs();
		    
		$this->end_controls_section();
		
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

		 // get url image
		$url 	= $settings['image']['url'];
		if ( empty( $url ) ) {
			return;
		}

		// get 
		$title 	= $settings['title'];
		$description 	= $settings['description'];

		$alt_img = $title ? $title : esc_html__( 'Awards', 'hotelft' );

		// get link 
		$link_title             = $settings['link_title']['url'];
		$link_title_is_external = $settings['link_title']['is_external'];
		$link_title_target      = ( $link_title_is_external == 'on' ) ? 'target="_blank"' : '';

		 ?>
            
        <div class="ova-awards">

			<div class="img">
				<img src="<?php echo esc_url( $url );?>" class="awards-img" alt="<?php echo esc_attr( $alt_img ); ?>">
			</div>

			<div class="info">

				<?php if ( !empty ($title)) : ?>
					<h2 class="title">
						<?php if( $link_title ){ ?>
							<a href="<?php echo esc_url( $link_title );?>" <?php printf( $link_title_target ); ?>>
						<?php } ?>
							<?php echo esc_html($title); ?>
						<?php if( $link_title ){ ?>
							</a>
						<?php } ?>
					</h2>
				<?php endif; ?>

				<?php if ( !empty ($description)) : ?>
					<p  class="description">
						<?php echo esc_html($description) ; ?>
					</p>
				<?php endif; ?>

			</div>
			
		</div>

		<?php
	}

	
}
$widgets_manager->register( new hotelft_Elementor_Awards() );