<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Hotelft_Elementor_Heading extends Widget_Base {

	
	public function get_name() {
		return 'hotelft_elementor_heading';
	}

	
	public function get_title() {
		return esc_html__( 'Ova Heading', 'hotelft' );
	}

	
	public function get_icon() {
		return 'eicon-heading';
	}

	
	public function get_categories() {
		return [ 'hotelft' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'hotelft' ),
			]
		);	
			

			// Add Class control
			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'hotelft' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__( 'Add Your Heading Text Here', 'hotelft' ),
				]
			);

			$this->add_control(
				'show_line_before',
				[
					'label' => esc_html__( 'Show Line', 'hotelft' ),
					'type' => Controls_Manager::SWITCHER,
					'default' => 'no',
					'label_on' => esc_html__( 'Show', 'hotelft' ),
					'label_off' => esc_html__( 'Hide', 'hotelft' ),
				]
			);

			$this->add_control(
				'title_link',
				[
					'label' 		=> esc_html__( 'Link', 'hotelft' ),
					'type' 			=> Controls_Manager::URL,
					'placeholder' 	=> esc_html__( 'https://your-link.com', 'hotelft' ),
					'show_external' => true,
					'default' => [
						'url' => '',
					],
				]
			);

			$this->add_control(
				'html_tag',
				[
					'label' 	=> esc_html__( 'HTML Tag', 'hotelft' ),
					'type' 		=> Controls_Manager::SELECT,
					'default' 	=> 'h2',
					'options' 	=> [
						'h1' 	=> esc_html__('H1', 'hotelft'),
						'h2' 	=> esc_html__('H2', 'hotelft'),
						'h3' 	=> esc_html__('H3', 'hotelft'),
						'h4'	=> esc_html__('H4', 'hotelft'),
						'h5' 	=> esc_html__('H5', 'hotelft'),
						'h6' 	=> esc_html__('H6', 'hotelft'),
						'p' 	=> esc_html__('p', 'hotelft'),
					]
				]
			);

			$this->add_responsive_control(
				'align',
				[
					'label' => esc_html__( 'Alignment', 'hotelft' ),
					'type' 	=> Controls_Manager::CHOOSE,
					'options' => [
						'left' => [
							'title' => esc_html__( 'Left', 'hotelft' ),
							'icon' 	=> 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'hotelft' ),
							'icon' 	=> 'eicon-text-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'hotelft' ),
							'icon' 	=> 'eicon-text-align-right',
						],
						'justify' => [
							'title' => esc_html__( 'Justified', 'hotelft' ),
							'icon' 	=> 'eicon-text-align-justify',
						],
					],
					'default' => '',
					'selectors' => [
						'{{WRAPPER}}' => 'text-align: {{VALUE}};',
					],
				]
			);

		$this->end_controls_section();

		/* Begin title Style */
		$this->start_controls_section(
            'title_style',
            [
                'label' => esc_html__( 'Title', 'hotelft' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'title_typography',
					'selector' 	=> '{{WRAPPER}} .ova-heading .title',
				]
			);

			$this->add_control(
				'title_color',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading .title' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ova-heading .title a' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'title_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading .title:hover' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ova-heading .title:hover a' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
	            'title_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-heading .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
	            'title_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-heading .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End title style */

		/* Begin line Style */
		$this->start_controls_section(
            'line_style',
            [
                'label' => esc_html__( 'Line', 'hotelft' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
                'condition' => [
                	'show_line_before' => 'yes'
                ]
            ]
        );

        	$this->add_control(
	            'line_color',
	            [
	                'label' 	=> esc_html__( 'Color', 'hotelft' ),
	                'type' 		=> Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .ova-heading.ova-line .title:before'=>'background-color:{{VALUE}};', 
	                ]
	            ]
	        );

	        $this->add_control(
				'line_left',
				[
					'label' 		=> esc_html__( 'Left', 'hotelft' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' 	=> 0,
							'max' 	=> 100,
							'step' 	=> 5,
						],
						'%' => [
							'min' 	=> 0,
							'max' 	=> 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading.ova-line .title:before'=> 'left: {{SIZE}}{{UNIT}}',
					],
				]
			);

			$this->add_control(
				'line_bottom',
				[
					'label' 		=> esc_html__( 'Bottom', 'hotelft' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' 	=> -100,
							'max' 	=> 100,
							'step' 	=> 5,
						],
						'%' => [
							'min' 	=> -100,
							'max' 	=> 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading.ova-line .title:before' => 'bottom: {{SIZE}}{{UNIT}}',
					],
				]
			);

	        $this->add_responsive_control(
				'line_width',
				[
					'label' 		=> esc_html__( 'Width', 'hotelft' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' 	=> 0,
							'max' 	=> 100,
							'step' 	=> 5,
						],
						'%' => [
							'min' 	=> 0,
							'max' 	=> 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading.ova-line .title:before' => 'width: {{SIZE}}{{UNIT}}'
					]
				]
			);

			$this->add_responsive_control(
				'line_height',
				[
					'label' 		=> esc_html__( 'Height', 'hotelft' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' 	=> 0,
							'max' 	=> 100,
							'step' 	=> 5,
						],
						'%' => [
							'min' 	=> 0,
							'max' 	=> 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading.ova-line .title:before'=> 'height:{{SIZE}}{{UNIT}}',
					],
				]
			);

			$this->add_control(
	            'linbe_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-heading.ova-line .title:before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_control(
	            'line_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-heading.ova-line .title:before' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End line style */
		
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

		$title 			  = $settings['title'];
		$title_link 	  = $settings['title_link']['url'];
		$target 		  = $settings['title_link']['is_external'] ? ' target="_blank"' : '';
		$show_line_before = $settings['show_line_before'];

		 ?>

		 	<div class="ova-heading <?php if( $show_line_before === "yes") echo 'ova-line'; ?>">
		 	   <?php echo '<'. esc_html( $settings['html_tag'] ) .' class="title">'; ?>
					<?php if ( $title_link ): ?>
						<a href="<?php echo esc_url( $title_link ); ?>"<?php echo esc_html( $target ); ?>>
							<?php echo esc_html( $title ); ?>
						</a>
					<?php else: ?>
						<?php echo esc_html( $title ); ?>
					<?php endif; ?>
				<?php echo '</'. esc_html( $settings['html_tag'] ) .'>' ?>
		    </div>

		<?php
	}

	
}
$widgets_manager->register( new Hotelft_Elementor_Heading() );