<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Background;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Hotelft_Elementor_Hotel extends Widget_Base {

	
	public function get_name() {
		return 'hotelft_elementor_hotel';
	}

	
	public function get_title() {
		return esc_html__( 'Hotel', 'hotelft' );
	}

	
	public function get_icon() {
		return 'eicon-image-hotspot';
	}

	
	public function get_categories() {
		return [ 'hotelft' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'hotelft' ),
			]
		);	
			
			
			// Add Class control
		    $this->add_control(
				'link',
				[
					'label' => esc_html__( 'Link', 'hotelft' ),
					'type' => Controls_Manager::URL,
					'dynamic' => [
						'active' => true,
					],
					'placeholder' => esc_html__( 'https://your-link.com', 'hotelft' ),
				]
			);

			$this->add_control(
				'image',
				[
					'label' => esc_html__( 'Image', 'hotelft' ),
					'type' => Controls_Manager::MEDIA,
					'dynamic' => [
						'active' => true,
					],
					'default' => [
						'url' => Utils::get_placeholder_image_src(),
					],
					'separator' => 'before'
				]
			);
				
			$this->add_control(
				'name',
				[
					'label' => esc_html__( 'Name', 'hotelft' ),
					'type' => Controls_Manager::TEXT,
					'default' => esc_html__( 'Hotel FT. Manchester', 'hotelft' ),
				]
			);

			$this->add_control(
				'icon_class',
				[
					'label' => esc_html__( 'Icon', 'hotelft' ),
					'type' => Controls_Manager::ICONS,
					'default' 	=> [
						'value' 	=> 'fas fa-map-marker-alt',
						'library' 	=> 'all',
					],
				]
			);

			$this->add_control(
				'location',
				[
					'label' => esc_html__( 'Location', 'hotelft' ),
					'type' => Controls_Manager::TEXTAREA,
					'default' => esc_html__( '4517 Washington Ave. Manchester, Kentucky 39495', 'hotelft' ),
				]
			);

		$this->end_controls_section();

		/* Begin image style */
		$this->start_controls_section(
			'section_image_style',
			[
				'label' => esc_html__( 'Image', 'hotelft' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

		    $this->add_group_control(
				\Elementor\Group_Control_Background::get_type(),
				[
					'name' => 'overlay_bg_hotel',
					'label' => __( 'Background Overlay', 'hotelft' ),
					'selector' => '{{WRAPPER}} .ova-hotel .mask',
				]
		    );

			$this->add_responsive_control(
	            'image_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-hotel .hotel-img, {{WRAPPER}} .ova-hotel' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

		$this->end_controls_section();
		/* End image style */

		/* Begin name Style */
		$this->start_controls_section(
            'name_style',
            [
                'label' => esc_html__( 'Name', 'hotelft' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'name_typography',
					'selector' 	=> '{{WRAPPER}} .ova-hotel .info .name',
				]
			);

			$this->add_control(
				'name_color',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-hotel .info .name' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'name_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-hotel:hover .info .name' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
	            'name_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-hotel .info .name' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End name style */

		/* Begin location Style */
		$this->start_controls_section(
            'location_style',
            [
                'label' => esc_html__( 'Location', 'hotelft' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'location_typography',
					'selector' 	=> '{{WRAPPER}} .ova-hotel .info .location',
				]
			);

			$this->add_control(
				'location_color',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-hotel .info .location' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'location_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-hotel:hover .info .location' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
	            'location_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-hotel .info .location' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End location style */
		
		/* Begin icon Style */
		$this->start_controls_section(
            'icon_style',
            [
                'label' => esc_html__( 'Icon Location', 'hotelft' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'icon_typography',
					'selector' 	=> '{{WRAPPER}} .ova-hotel .info .location i',
				]
			);

			$this->add_control(
				'icon_color',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-hotel .info .location i' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'icon_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-hotel:hover .info .location i' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
	            'icon_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-hotel .info .location i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End icon style */
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

		$url 	        = $settings['image']['url'];
        if ( empty( $url ) ) {
			return;
		}

		$name 			= $settings['name'];
		$icon_class 	= $settings['icon_class']['value'];
		$location 	    = $settings['location'];
		$link 	        = $settings['link']['url'];
		$target 		= $settings['link']['is_external'] ? ' target="_blank"' : '';
		$alt_img = $name ? $name : esc_html__( 'Hotel', 'hotelft' );

		 ?>

        <?php if( $link ){ ?>
			<a href="<?php echo esc_url( $link );?>" <?php printf( $target ); ?>>
		<?php } ?>

			<div class="ova-hotel">
				<img src="<?php echo esc_url( $url );?>" class="hotel-img" alt="<?php echo esc_attr( $alt_img ); ?>">
				<div class="mask"></div>
				<div class="info">
					<?php if ( !empty ($name)) : ?>
						<h2 class="name">
							<?php echo esc_html($name); ?>
						</h2>
					<?php endif; ?>

					<?php if ( !empty ($location)) : ?>
						<div class="location">
							<i class="<?php echo esc_attr($icon_class) ; ?>"></i>
							<?php echo esc_html($location) ; ?>
						</div>
					<?php endif; ?>
				</div>	

			</div>

		<?php if( $link ){ ?>
			</a>
		<?php } ?>

		<?php
	}

	
}
$widgets_manager->register( new Hotelft_Elementor_Hotel() );