<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Border;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Hotelft_Elementor_Offer extends Widget_Base {

	
	public function get_name() {
		return 'hotelft_elementor_offer';
	}

	
	public function get_title() {
		return esc_html__( 'Offer', 'hotelft' );
	}

	
	public function get_icon() {
		return 'eicon-slider-album';
	}

	
	public function get_categories() {
		return [ 'hotelft' ];
	}

	public function get_script_depends() {
		// Carousel
		wp_enqueue_style( 'owl-carousel', get_template_directory_uri().'/assets/libs/carousel/assets/owl.carousel.min.css' );
		wp_enqueue_script( 'owl-carousel', get_template_directory_uri().'/assets/libs/carousel/owl.carousel.min.js', array('jquery'), false, true );
		return [ 'hotelft-elementor-offer' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'hotelft' ),
			]
		);	
			
			
			// Add Class control
			$repeater = new \Elementor\Repeater();

			$repeater->add_control(
				'link',
				[
					'label' => esc_html__( 'Link', 'hotelft' ),
					'type' => Controls_Manager::URL,
					'dynamic' => [
						'active' => true,
					],
					'placeholder' => esc_html__( 'https://your-link.com', 'hotelft' ),
					'show_label' => true,
					'default' => [
						'url' => '',
					],
				]
			);

			$repeater->add_control(
				'image',
				[
					'label'   => esc_html__( 'Choose Image', 'hotelft' ),
					'type'    => Controls_Manager::MEDIA,
					'default' => [
						'url' => Utils::get_placeholder_image_src(),
					],
				]
			);

			$repeater->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'hotelft' ),
					'type' => Controls_Manager::TEXT,
					'default' => esc_html__( 'Sale off 20% for the first 3 nights', 'hotelft' ),
				]
			);

			$repeater->add_control(
				'category',
				[
					'label' => esc_html__( 'Category', 'hotelft' ),
					'type' => Controls_Manager::TEXT,
					'default' => esc_html__( 'All hotels', 'hotelft' ),
				]
			);

			$repeater->add_control(
				'icon_category',
				[
					'label' => esc_html__( 'Icon Category', 'hotelft' ),
					'type' => Controls_Manager::ICONS,
					'default' => [
						'value' => 'flaticon flaticon-hotels',
						'library' => 'all',
					],
				]
			);

			$repeater->add_control(
				'date_start',
				[
					'label' 		=> esc_html__( 'Date Start', 'hotelft' ),
					'type' 			=> Controls_Manager::DATE_TIME,
					'default'       => gmdate( 'Y-m-d H:i'),
				]
			);

			$repeater->add_control(
				'date_end',
				[
					'label' 		=> esc_html__( 'Date End', 'hotelft' ),
					'type' 			=> Controls_Manager::DATE_TIME,
					'default'       => gmdate( 'Y-m-d H:i', strtotime( '+1 week' ) ),
				]
			);

			$repeater->add_control(
				'icon_date',
				[
					'label' => esc_html__( 'Icon Date', 'hotelft' ),
					'type' => Controls_Manager::ICONS,
					'default' => [
						'value' => 'iconly iconly-Time-Circle icli',
						'library' => 'all',
					],
				]
			);

			$repeater->add_control(
				'description',
				[
					'label' => esc_html__( 'Description', 'hotelft' ),
					'type' => Controls_Manager::TEXTAREA,
					'default' => esc_html__( 'You will save your money when you stay in longer, a discount for 20%, free breakfasts, Free airport shuttle and free laundry service.', 'hotelft' ),
				]
			);

			$this->add_control(
				'tab_item',
				[
					'label'		=> esc_html__( 'Tabs', 'hotelft' ),
					'type'		=> Controls_Manager::REPEATER,
					'fields'  	=> $repeater->get_controls(),
					'default' 	=> [
						[
							'title' => esc_html__('Sale off 20% for the first 3 nights', 'hotelft'),
						],
						[
							'title' => esc_html__('Sale off 20% for the first 3 nights and 3 day', 'hotelft'),
						],
						[
							'title' => esc_html__('Free breakfast for 1 week', 'hotelft'),
						],
						[
							'title' => esc_html__('Sale off 20% for the first 3 nights and 3 day', 'hotelft'),
						],
						[
							'title' => esc_html__('Sale off 10% for the first 3 nights', 'hotelft'),
						],
					],
				]
			);

		$this->end_controls_section();

		/*****************************************************************
						START SECTION ADDITIONAL
		******************************************************************/

		$this->start_controls_section(
			'section_additional_options',
			[
				'label' => esc_html__( 'Additional Options', 'hotelft' ),
			]
		);

			$this->add_control(
				'margin_items',
				[
					'label'   => esc_html__( 'Margin Right Items', 'hotelft' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 30,
				]
				
			);

			$this->add_control(
				'stagePadding',
				[
					'label'   => esc_html__( 'stagePadding', 'hotelft' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 180,
				]
				
			);

			$this->add_control(
				'item_number',
				[
					'label'       => esc_html__( 'Item Number', 'hotelft' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Number Item', 'hotelft' ),
					'default'     => 2,
				]
			);

			$this->add_control(
				'slides_to_scroll',
				[
					'label'       => esc_html__( 'Slides to Scroll', 'hotelft' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Set how many slides are scrolled per swipe.', 'hotelft' ),
					'default'     => 1,
				]
			);

			$this->add_control(
				'pause_on_hover',
				[
					'label'   => esc_html__( 'Pause on Hover', 'hotelft' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'hotelft' ),
						'no'  => esc_html__( 'No', 'hotelft' ),
					],
					'frontend_available' => true,
				]
			);


			$this->add_control(
				'infinite',
				[
					'label'   => esc_html__( 'Infinite Loop', 'hotelft' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'hotelft' ),
						'no'  => esc_html__( 'No', 'hotelft' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay',
				[
					'label'   => esc_html__( 'Autoplay', 'hotelft' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'hotelft' ),
						'no'  => esc_html__( 'No', 'hotelft' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay_speed',
				[
					'label'     => esc_html__( 'Autoplay Speed', 'hotelft' ),
					'type'      => Controls_Manager::NUMBER,
					'default'   => 3000,
					'step'      => 500,
					'condition' => [
						'autoplay' => 'yes',
					],
					'frontend_available' => false,
				]
			);

			$this->add_control(
				'autoWidth',
				[
					'label'   => esc_html__( 'AutoWidth', 'hotelft' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'no',
					'options' => [
						'yes' => esc_html__( 'Yes', 'hotelft' ),
						'no'  => esc_html__( 'No', 'hotelft' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'smartspeed',
				[
					'label'   => esc_html__( 'Smart Speed', 'hotelft' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 500,
				]
			);

			$this->add_control(
				'dot_control',
				[
					'label'   => esc_html__( 'Show Dots', 'hotelft' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'hotelft' ),
						'no'  => esc_html__( 'No', 'hotelft' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'nav_control',
				[
					'label'   => esc_html__( 'Show Nav', 'hotelft' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'no',
					'options' => [
						'yes' => esc_html__( 'Yes', 'hotelft' ),
						'no'  => esc_html__( 'No', 'hotelft' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'nav_left',
				[
					'label'       	=> esc_html__( 'Icon Left', 'hotelft' ),
					'type'        	=> Controls_Manager::TEXT,
					'default'     	=> esc_html__( 'flaticon flaticon-left', 'hotelft' ),
					'condition' 	=> [
						'nav_control' => 'yes',
					],
				]
			);

			$this->add_control(
				'nav_right',
				[
					'label'       	=> esc_html__( 'Icon Right', 'hotelft' ),
					'type'        	=> Controls_Manager::TEXT,
					'default'     	=> esc_html__( 'flaticon flaticon-right-arrow', 'hotelft' ),
					'condition' 	=> [
						'nav_control' => 'yes',
					],
				]
			);

		$this->end_controls_section();

		/****************************  END SECTION ADDITIONAL *********************/
        
        $this->start_controls_section(
			'section_offer',
			[
				'label' => esc_html__( 'Offer', 'hotelft' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
            
            $this->add_responsive_control(
				'offer_image_border_radius',
				[
					'label'      => esc_html__( 'Border Radius', 'hotelft' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-offer .offer-img img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'content_heading',
				[
					'label'      => esc_html__( 'Content', 'hotelft' ),
					'type'       => Controls_Manager::HEADING,
					'separator'  => 'before'
				]
			);

			$this->add_responsive_control(
				'content_max_height',
				[
					'label' 	=> esc_html__( 'Max Height', 'hotelft' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 100,
							'max' => 500,
						],
					],
					'size_units' 	=> [ 'px', '%' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-offer .offer-img .content' => 'max-height: {{SIZE}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_title',
			[
				'label' => esc_html__( 'Title', 'hotelft' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'     => 'title_typography',
					'selector' => '{{WRAPPER}} .ova-offer .offer-img .info .title',
				]
			);

			$this->add_control(
				'title_color',
				[
					'label'     => esc_html__( 'Color', 'hotelft' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-offer .offer-img .info .title' => 'color : {{VALUE}};',
					],
				]
			);
            
            $this->add_responsive_control(
				'title_padding',
				[
					'label'      => esc_html__( 'Padding', 'hotelft' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-offer .offer-img .info .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_category',
			[
				'label' => esc_html__( 'Category', 'hotelft' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'     => 'category_typography',
					'selector' => '{{WRAPPER}} .ova-offer .offer-img .content .category',
				]
			);

			$this->add_control(
				'category_color',
				[
					'label'     => esc_html__( 'Color', 'hotelft' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-offer .offer-img .content .category' => 'color : {{VALUE}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_date',
			[
				'label' => esc_html__( 'Date', 'hotelft' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'     => 'date_typography',
					'selector' => '{{WRAPPER}} .ova-offer .offer-img .content .date',
				]
			);

			$this->add_control(
				'date_color',
				[
					'label'     => esc_html__( 'Color', 'hotelft' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-offer .offer-img .content .date' => 'color : {{VALUE}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_icon',
			[
				'label' => esc_html__( 'Icon', 'hotelft' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'     => 'icon_typography',
					'selector' => '{{WRAPPER}} .ova-offer .offer-img .content i',
				]
			);

			$this->add_control(
				'icon_color',
				[
					'label'     => esc_html__( 'Color', 'hotelft' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-offer .offer-img .content i' => 'color : {{VALUE}};',
					],
				]
			);
            
            $this->add_responsive_control(
				'icon_padding',
				[
					'label'      => esc_html__( 'Padding', 'hotelft' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-offer .offer-img .content i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();


		$this->start_controls_section(
			'section_description',
			[
				'label' => esc_html__( 'Description', 'hotelft' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'     => 'description_typography',
					'selector' => '{{WRAPPER}} .ova-offer .offer-img .content .description',
				]
			);

			$this->add_group_control(
	            Group_Control_Border::get_type(), [
	                'name' 		=> 'des_border',
	                'selector' 	=> '{{WRAPPER}}  .ova-offer .offer-img .content .description',
	            ]
	        );

			$this->add_control(
				'description_color',
				[
					'label'     => esc_html__( 'Color', 'hotelft' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-offer .offer-img .content .description' => 'color : {{VALUE}};',
					],
				]
			);
            
            $this->add_responsive_control(
				'description_padding',
				[
					'label'      => esc_html__( 'Padding', 'hotelft' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-offer .offer-img .content .description' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		/* Begin Nav Style */
		$this->start_controls_section(
            'nav_style',
            [
                'label' => esc_html__( 'Nav Control', 'hotelft' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
                 'condition' => [
					'nav_control' => 'yes',
				]
            ]
        );

        	$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'nav_typography',
					'selector' 	=> '{{WRAPPER}} .ova-offer .owl-nav button i',
				]
			);

			$this->add_responsive_control(
				'nav_size',
				[
					'label' 	=> esc_html__( 'Size', 'hotelft' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-offer .owl-nav button:before' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
					'description' => esc_html__('Circle hover size', 'hotelft')
				]
			);

			$this->start_controls_tabs( 'tabs_nav_style' );

				$this->start_controls_tab(
		            'tab_nav_normal',
		            [
		                'label' => esc_html__( 'Normal', 'hotelft' ),
		            ]
		        );

					$this->add_control(
			            'nav_color_normal',
			            [
			                'label' 	=> esc_html__( 'Color', 'hotelft' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-offer .owl-nav button i' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

				$this->end_controls_tab();

				$this->start_controls_tab(
		            'tab_nav_hover',
		            [
		                'label' => esc_html__( 'Hover', 'hotelft' ),
		            ]
		        );

					$this->add_control(
			            'nav_color_hover',
			            [
			                'label' 	=> esc_html__( 'Color', 'hotelft' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-offer .owl-nav button:hover i' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

				$this->end_controls_tab();
			$this->end_controls_tabs();

			$this->add_group_control(
	            Group_Control_Border::get_type(), [
	                'name' 		=> 'nav_border',
	                'selector' 	=> '{{WRAPPER}} .ova-offer .owl-nav button:before',
	                'separator' => 'before',
	            ]
	        );

	        $this->add_control(
	            'nav_border_color_hover',
	            [
	                'label' 	=> esc_html__( 'Color Hover', 'hotelft' ),
	                'type' 		=> Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .ova-offer .owl-nav button:hover:before' => 'border-color: {{VALUE}}',
	                ],
	                'description' => esc_html__('Circle color hover', 'hotelft')
	            ]
	        );

	        $this->add_responsive_control(
	            'nav_margin_prev',
	            [
	                'label' 		=> esc_html__( 'Margin Prev', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-offer .owl-nav button.owl-prev' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	                'description' => esc_html__('Icon space between', 'hotelft')
	            ]
	        );

        $this->end_controls_section();
        /* End Nav Style */

        /* Begin Dots Style */
		$this->start_controls_section(
            'dots_style',
            [
                'label' => esc_html__( 'Dots', 'hotelft' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
                'condition' => [
					'dot_control' => 'yes',
				]
            ]
        );

            $this->add_responsive_control(
				'dots_margin',
				[
					'label'      => esc_html__( 'Margin', 'hotelft' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-offer .owl-dots' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->start_controls_tabs( 'tabs_dots_style' );
				
				$this->start_controls_tab(
		            'tab_dots_normal',
		            [
		                'label' => esc_html__( 'Normal', 'hotelft' ),
		            ]
		        );

		            $this->add_control(
						'dot_color',
						[
							'label' 	=> esc_html__( 'Color', 'hotelft' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-offer .owl-dots .owl-dot span' => 'background-color: {{VALUE}}',
							],
						]
					);

					$this->add_responsive_control(
						'dots_width',
						[
							'label' 	=> esc_html__( 'Width', 'hotelft' ),
							'type' 		=> Controls_Manager::SLIDER,
							'range' => [
								'px' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'size_units' 	=> [ 'px' ],
							'selectors' 	=> [
								'{{WRAPPER}} .ova-offer .owl-dots .owl-dot span' => 'width: {{SIZE}}{{UNIT}};',
							],
						]
					);

					$this->add_responsive_control(
						'dots_height',
						[
							'label' 	=> esc_html__( 'Height', 'hotelft' ),
							'type' 		=> Controls_Manager::SLIDER,
							'range' => [
								'px' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'size_units' 	=> [ 'px' ],
							'selectors' 	=> [
								'{{WRAPPER}} .ova-offer .owl-dots .owl-dot span' => 'height: {{SIZE}}{{UNIT}};',
							],
						]
					);

					$this->add_control(
			            'dots_border_radius',
			            [
			                'label' 		=> esc_html__( 'Border Radius', 'hotelft' ),
			                'type' 			=> Controls_Manager::DIMENSIONS,
			                'size_units' 	=> [ 'px', '%' ],
			                'selectors' 	=> [
			                    '{{WRAPPER}} .ova-offer .owl-dots .owl-dot span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			                ],
			            ]
			        );

		        $this->end_controls_tab();

		        $this->start_controls_tab(
		            'tab_dots_active',
		            [
		                'label' => esc_html__( 'Active', 'hotelft' ),
		            ]
		        );

		             $this->add_control(
						'dot_color_active',
						[
							'label' 	=> esc_html__( 'Color', 'hotelft' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-offer .owl-dots .owl-dot.active span' => 'background-color: {{VALUE}}',
							],
						]
					);

					$this->add_responsive_control(
						'dots_width_active',
						[
							'label' 	=> esc_html__( 'Width', 'hotelft' ),
							'type' 		=> Controls_Manager::SLIDER,
							'range' => [
								'px' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'size_units' 	=> [ 'px' ],
							'selectors' 	=> [
								'{{WRAPPER}} .ova-offer .owl-dots .owl-dot.active span' => 'width: {{SIZE}}{{UNIT}};',
							],
						]
					);

					$this->add_responsive_control(
						'dots_height_active',
						[
							'label' 	=> esc_html__( 'Height', 'hotelft' ),
							'type' 		=> Controls_Manager::SLIDER,
							'range' => [
								'px' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'size_units' 	=> [ 'px' ],
							'selectors' 	=> [
								'{{WRAPPER}} .ova-offer .owl-dots .owl-dot.active span' => 'height: {{SIZE}}{{UNIT}};',
							],
						]
					);

					$this->add_control(
			            'dots_border_radius_active',
			            [
			                'label' 		=> esc_html__( 'Border Radius', 'hotelft' ),
			                'type' 			=> Controls_Manager::DIMENSIONS,
			                'size_units' 	=> [ 'px', '%' ],
			                'selectors' 	=> [
			                    '{{WRAPPER}} .ova-offer .owl-dots .owl-dot.active span' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			                ],
			            ]
			        );

		        $this->end_controls_tab();
			$this->end_controls_tabs();

        $this->end_controls_section();
        /* End Dots Style */
		
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

		$settings = $this->get_settings();

		$tab_item = $settings['tab_item'];

		$data_options['items']              = $settings['item_number'];
		$data_options['slideBy']            = $settings['slides_to_scroll'];
		$data_options['margin']             = $settings['margin_items'];
		$data_options['stagePadding']       = $settings['stagePadding'];
		$data_options['autoplayHoverPause'] = $settings['pause_on_hover'] === 'yes' ? true : false;
		$data_options['loop']               = $settings['infinite'] === 'yes' ? true : false;
		$data_options['autoplay']           = $settings['autoplay'] === 'yes' ? true : false;
		$data_options['autoWidth']          = $settings['autoWidth'] === 'yes' ? true : false;
		$data_options['autoplayTimeout']    = $settings['autoplay_speed'];
		$data_options['smartSpeed']         = $settings['smartspeed'];
		$data_options['rtl']				= is_rtl() ? true: false;
		$data_options['dots']               = $settings['dot_control'] === 'yes' ? true : false;
		$data_options['nav']                = $settings['nav_control'] === 'yes' ? true : false;
		$data_options['nav_left']           = $settings['nav_left'];
		$data_options['nav_right']          = $settings['nav_right'];

		 ?>

		 	<div class="ova-offer">

				<div class="offer-carousel owl-carousel owl-theme" data-options="<?php echo esc_attr(json_encode($data_options)) ?>">
					<?php if(!empty($tab_item)) : foreach ($tab_item as $items) : 
					
						$img_url 	 = $items['image']['url'];
						$img_alt 	 = isset( $items['image']['alt'] ) ? $items['image']['alt'] : esc_html__('Offer','hotelft');

						$title       = $items['title'];
						$description = $items['description'];
						$category    = $items['category'];

						$icon_category = $items['icon_category']['value'];
						$icon_date     = $items['icon_date']['value'];

						$link        = $items['link'];
						$nofollow    = ( isset( $link['nofollow'] ) && $link['nofollow'] ) ? ' rel="nofollow"' : '';
						$target      = ( isset( $link['is_external'] ) && $link['is_external'] !== '' ) ? ' target="_blank"' : '';

						$date_start      = date('d M',strtotime($items['date_start']) );
						$date_end        = date('d M',strtotime($items['date_end']) );
						?>

	                        <?php if ( !empty($link['url'])) : ?>	
							<a href="<?php echo esc_url( $link['url'] ); ?> "  <?php echo esc_attr( $target ); ?> <?php echo esc_attr( $nofollow ); ?>>
						    <?php endif; ?>

								<div class="item">
									<div class="offer-img">

										<img src="<?php echo esc_url( $img_url ); ?>" alt="<?php echo esc_attr( $img_alt ); ?>">

										<div class="info">
											<?php if ( !empty ($title)) : ?>
												<h3 class="title">
													<?php echo esc_html($title); ?>
												</h3>
											<?php endif; ?>
										</div>

										<div class="content">
											<?php if ( !empty ($category)) : ?>
												<span class="category">
													<i class="<?php echo esc_attr($icon_category); ?>"></i>
													<?php echo esc_html($category); ?>
												</span>
											<?php endif; ?>
											<?php if ( !empty ($date_start)) : ?>
												<div class="date">
													<i class="<?php echo esc_attr($icon_date); ?>"></i>
													<?php echo esc_html($date_start); ?>
													<span>-</span>
													<?php echo esc_html($date_end); ?>
												</div>
											<?php endif; ?>
											<?php if ( !empty ($description)) : ?>
												<p class="description">
													<?php echo esc_html($description); ?>
												</p>
											<?php endif; ?>
									    </div>

									</div>
								</div>
								
							<?php if ( !empty($link['url']) ) : ?>
						        </a>
					        <?php endif; ?>

					<?php endforeach; endif; ?>

				</div>

			</div>

		<?php
	}

	
}
$widgets_manager->register( new Hotelft_Elementor_Offer() );