<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Hotelft_Elementor_Place extends Widget_Base {

	
	public function get_name() {
		return 'hotelft_elementor_place';
	}

	
	public function get_title() {
		return esc_html__( 'Place', 'hotelft' );
	}

	
	public function get_icon() {
		return 'eicon-google-maps';
	}

	
	public function get_categories() {
		return [ 'hotelft' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'hotelft' ),
			]
		);	
			
			// Add Class control

			$this->add_control(
				'image',
				[
					'label' => esc_html__( 'Image', 'hotelft' ),
					'type' => Controls_Manager::MEDIA,
					'dynamic' => [
						'active' => true,
					],
					'default' => [
						'url' => Utils::get_placeholder_image_src(),
					],
					'separator' => 'before'
				]
			);

			$this->add_control(
				'place',
				[
					'label' => esc_html__( 'Place', 'hotelft' ),
					'type' => Controls_Manager::TEXT,
					'default' => esc_html__( 'Lakeside Asia', 'hotelft' ),
				]
			);

			$this->add_control(
				'distance',
				[
					'label' => esc_html__( 'Distance', 'hotelft' ),
					'type' => Controls_Manager::TEXT,
					'default' => esc_html__( '500m', 'hotelft' ),
				]
			);

			$this->add_control(
				'link',
				[
					'label' => esc_html__( 'Link', 'hotelft' ),
					'type' => Controls_Manager::URL,
					'dynamic' => [
						'active' => true,
					],
					'default' => [
						'url' => '#',
					],
					'placeholder' => esc_html__( 'https://your-link.com', 'hotelft' ),
				]
			);

		$this->end_controls_section();

		/* Begin place Style */
		$this->start_controls_section(
            'place_style',
            [
                'label' => esc_html__( 'Place', 'hotelft' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'place_typography',
					'selector' 	=> '{{WRAPPER}} .ova-place .info .place',
				]
			);

			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' 		=> 'place_border',
					'label' 	=> esc_html__( 'Border', 'hotelft' ),
					'selector' 	=> '{{WRAPPER}} .ova-place .info .place',
					'separator' => 'before',
				]
			);

			$this->add_control(
				'place_color',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-place .info .place' => 'color : {{VALUE}};'
					],
				]
			);

			$this->add_responsive_control(
	            'place_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-place .info .place' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
	            'place_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-place .info .place' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End place style */

		/* Begin distance Style */
		$this->start_controls_section(
            'distance_style',
            [
                'label' => esc_html__( 'Distance', 'hotelft' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'distance_typography',
					'selector' 	=> '{{WRAPPER}} .ova-place .info .distance',
				]
			);

			$this->add_control(
				'distance_color',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-place .info .distance, {{WRAPPER}} .ova-place .info .distance a' => 'color : {{VALUE}};'
					],
				]
			);

			$this->add_control(
				'distance_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-place .info .distance:hover, {{WRAPPER}} .ova-place .info .distance:hover a' => 'color : {{VALUE}};'
					],
				]
			);

			$this->add_responsive_control(
	            'distance_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-place .info .distance' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End distance style */

		/* Begin image style */
		$this->start_controls_section(
			'section_image_style',
			[
				'label' => esc_html__( 'Image', 'hotelft' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_responsive_control(
				'image_max_width',
				[
					'label' 	=> esc_html__( 'Max Width', 'hotelft' ),
					'type' 		=> Controls_Manager::SLIDER,
					'default' 	=> [
						'unit' 	=> 'px',
					],
					'tablet_default' => [
						'unit' => 'px',
					],
					'mobile_default' => [
						'unit' => 'px',
					],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ '%', 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-place .img .place-img' => 'max-width: {{SIZE}}{{UNIT}}',
					],
				]
			);

			$this->add_responsive_control(
	            'image_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border radius', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-place .img, {{WRAPPER}} .ova-place' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

		$this->end_controls_section();
		/* End image style */

		// Place Element style Tab
		$this->start_controls_section(
			'section_style_place',
			[
				'label' => esc_html__( 'Place Element', 'hotelft' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

	        $this->add_control(
				'place_element_bgcolor',
				[
					'label' 	=> esc_html__( 'Background Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-place' => 'background-color : {{VALUE}};'
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'box_shadow_place_element',
					'label' => __( 'Box Shadow', 'hotelft' ),
					'selector' => '{{WRAPPER}} .ova-place',
				]
		    );

			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'box_shadow_place_element_hover',
					'label' => __( 'Box Shadow Hover', 'hotelft' ),
					'selector' => '{{WRAPPER}} .ova-place:hover',
				]
		    );
		    
		$this->end_controls_section();

	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

		// get url image
		$url 	= $settings['image']['url'];
		if ( empty( $url ) ) {
			return;
		}

		// get 
		$place    	= $settings['place'];
		$distance 	= $settings['distance'];

		$alt_img = $place ? $place : esc_html__( 'Place', 'hotelft' );

		// get link 
		$link 	= $settings['link']['url'];
		$target = $settings['link']['is_external'] ? 'target="_blank"' : '';

		 ?>

		 <div class="ova-place">

			<div class="img">
				<?php if ( $link ): ?>
					<a href="<?php echo esc_url( $link );?>" <?php printf( $target ); ?>>
						<img src="<?php echo esc_url( $url );?>" class="place-img" alt="<?php echo esc_attr( $alt_img ); ?>">
					</a>
				<?php else: ?>
					<img src="<?php echo esc_url( $url );?>" class="place-img" alt="<?php echo esc_attr( $alt_img ); ?>">
				<?php endif; ?>
			</div>

			<div class="info">

				<?php if ( !empty ($place)) : ?>
					<h3 class="place">
						<?php echo esc_html($place) ; ?>
					</h3>
				<?php endif; ?>

				<?php if ( !empty ($distance)) : ?>
					<span class="distance">
						<?php echo esc_html($distance); ?>
					</span>

				<?php endif; ?>

			</div>
			
		</div>

		<?php
	}

	
}
$widgets_manager->register( new Hotelft_Elementor_Place() );