<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Border;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Hotelft_Elementor_Room_List_2 extends Widget_Base {

	
	public function get_name() {
		return 'hotelft_elementor_room_list_2';
	}

	
	public function get_title() {
		return esc_html__( 'Room List 2', 'hotelft' );
	}

	
	public function get_icon() {
		return 'eicon-posts-grid';
	}

	
	public function get_categories() {
		return [ 'hotelft' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'hotelft' ),
			]
		);	
			
			// get categories
			$args_query	= [
				'taxonomy' 	=> 'product_cat',
				'orderby' 	=> 'name',
	        	'order'   	=> 'ASC'
			];
            
            $categories            = get_categories($args_query);
            $default_category      = array( 'all' => esc_html__( 'All', 'hotelft' ) );
            $categories_data       = array();
            $result                = array();      

            if ( $categories && is_array( $categories ) ) {
				foreach ( $categories as $category ) {
					$categories_data[$category->slug] = $category->cat_name;
				}
			}

			$result = array_merge( $default_category, $categories_data );
			

            // get custom taxonomy
			$taxonomy = array(
				'' => esc_html__( 'Select Taxonomy', 'hotelft' ),
			);

			$custom_taxonomy 	= get_option( 'ovabrw_custom_taxonomy', array() );
			$terms_value 		= array();

			if ( $custom_taxonomy ) {
				foreach ( $custom_taxonomy as $k => $value ) {
					$terms = get_terms( array(
					    'taxonomy' => $k,
					));

					if ( $terms && is_array( $terms ) ) {
						$taxonomy[$k] 	 = $value['name'];
						$terms_value[$k] = array(
							'name' 	=> $value['name'],
							'value' => array()
						);

						foreach ( $terms as $term ) {
							if ( is_object( $term ) ) {
								$terms_value[$k]['value'][$term->slug] = $term->name;
							}
						}
					}
				}
			}

			$this->add_control(
				'taxonomy',
				[
					'label' 	=> esc_html__( 'Select Taxonomy', 'hotelft' ),
					'type' 		=> \Elementor\Controls_Manager::SELECT,
					'default' 	=> '',
					'options' 	=> $taxonomy,
				]
			);

			if ( $terms_value && is_array( $terms_value ) ) {
				foreach ( $terms_value as $t => $v ) {
					if ( $v ) {
						$terms_default 	= array( '' => esc_html( 'Select ', 'hotelft' ) . esc_html( $v['name'] ) );
						$terms_result 	= array_merge( $terms_default, $v['value'] );
						$this->add_control(
							'taxonomy_'.esc_html($t),
							[
								'label' 	=> esc_html__( 'Select ', 'hotelft' ). esc_html( $v['name'] ),
								'type' 		=> \Elementor\Controls_Manager::SELECT,
								'default' 	=> '',
								'options' 	=> $terms_result,
								'condition' => [
									'taxonomy' => $t,
								],
							]
						);
					}
				}
			}

			$this->add_control(
				'categories',
				[
					'label' 	=> esc_html__( 'Select Category', 'hotelft' ),
					'type' 		=> Controls_Manager::SELECT,
					'default' 	=> 'all',
					'options' 	=> $result,
				]
			);

			$this->add_control(
				'posts_per_page',
				[
					'label' 	=> esc_html__( 'Posts Per Page', 'hotelft' ),
					'type' 		=> Controls_Manager::NUMBER,
					'default' 	=> 5,
				]
			);

			$this->add_control(
				'orderby',
				[
					'label' 	=> esc_html__( 'Order By', 'hotelft' ),
					'type' 		=> Controls_Manager::SELECT,
					'default' 	=> 'title',
					'options' 	=> [
						'title' => esc_html__( 'Title', 'hotelft' ),
						'ID' 	=> esc_html__( 'ID', 'hotelft' ),
						'date' 	=> esc_html__( 'Date', 'hotelft' ),
					],
				]
			);

			$this->add_control(
				'order',
				[
					'label' 	=> esc_html__( 'Order', 'hotelft' ),
					'type' 		=> Controls_Manager::SELECT,
					'default' 	=> 'ASC',
					'options' 	=> [
						'ASC' 	=> esc_html__( 'Ascending', 'hotelft' ),
						'DESC' 	=> esc_html__( 'Descending', 'hotelft' ),
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_room_list_style',
			[
				'label' => esc_html__( 'Grid Content', 'hotelft' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_responsive_control(
				'content_gap',
				[
					'label' 		=> esc_html__( 'Gap', 'hotelft' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 80,
							'step' => 5,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-room-list-2' => 'grid-gap: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' 		=> 'room_border',
					'label' 	=> esc_html__( 'Border', 'hotelft' ),
					'selector' 	=> '{{WRAPPER}} .ova-room-list-2 .room-content',
					'separator' => 'before',
				]
			);

			$this->add_responsive_control(
				'room_content_padding',
				[
					'label' 		=> esc_html__( 'Padding', 'hotelft' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-room-list-2 .room-content .room-meta' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_image_style',
			[
				'label' => esc_html__( 'Image', 'hotelft' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		    $this->add_responsive_control(
				'image_height',
				[
					'label' 	=> esc_html__( 'Height', 'hotelft' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 500,
						],
					],
					'size_units' 	=> [ 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-room-list-2 .room-content .room-image img' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'image_border_radius',
				[
					'label'      => esc_html__( 'Border Radius', 'hotelft' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-room-list-2 .room-content .room-image, {{WRAPPER}} .ova-room-list-2 .room-content .room-image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_room_title_style',
			[
				'label' => esc_html__( 'Room Title', 'hotelft' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'room_title_typography',
					'selector' 	=> '{{WRAPPER}} .ova-room-list-2 .room-content .room-meta .room-price-title .room-title',
				]
			);

			$this->add_control(
				'room_title_color_normal',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-room-list-2 .room-content .room-meta .room-price-title .room-title a' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'room_title_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-room-list-2 .room-content .room-meta .room-price-title .room-title:hover a' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'room_title_padding',
				[
					'label' 		=> esc_html__( 'Padding', 'hotelft' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-room-list-2 .room-content .room-meta .room-price-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_room_price_style',
			[
				'label' => esc_html__( 'Room Price', 'hotelft' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'room_price_typography',
					'selector' 	=> '{{WRAPPER}} .ova-room-list-2 .room-content .room-meta .room-price-title .room-price',
				]
			);

			$this->add_control(
				'room_price_color',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-room-list-2 .room-content .room-meta .room-price-title .room-price' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'room_price_bgcolor',
				[
					'label' 	=> esc_html__( 'Background Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-room-list-2 .room-content .room-meta .room-price-title .room-price' => 'background-color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'room_price_padding',
				[
					'label' 		=> esc_html__( 'Padding', 'hotelft' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-room-list-2 .room-content .room-meta .room-price-title .room-price' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'room_price_border_radius',
				[
					'label' 		=> esc_html__( 'Border Radius', 'hotelft' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-room-list-2 .room-content .room-meta .room-price-title .room-price' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_room_info_style',
			[
				'label' => esc_html__( 'Room Info', 'hotelft' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'room_info_typography',
					'selector' 	=> '{{WRAPPER}} .ova-room-list-2 .room-content .room-info li',
				]
			);

			$this->add_control(
				'room_info_color',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-room-list-2 .room-content .room-info li' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'room_info_bgcolor',
				[
					'label' 	=> esc_html__( 'Background Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-room-list-2 .room-content .room-info' => 'background-color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'room_info_padding',
				[
					'label' 		=> esc_html__( 'Padding', 'hotelft' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-room-list-2 .room-content .room-info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'room_info_border_radius',
				[
					'label' 		=> esc_html__( 'Border Radius', 'hotelft' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-room-list-2 .room-content .room-info' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'room_info_icon',
				[
					'label' 	=> esc_html__( 'Icon', 'hotelft' ),
					'type' 		=> \Elementor\Controls_Manager::HEADING,
				]
			);

				$this->add_group_control(
					Group_Control_Typography::get_type(),
					[
						'name' 		=> 'room_info_icon_typography',
						'selector' 	=> '{{WRAPPER}} .ova-room-list-2 .room-content .room-info li i',
					]
				);

				$this->add_control(
					'room_info_icon_color',
					[
						'label' 	=> esc_html__( 'Color', 'hotelft' ),
						'type' 		=> Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-room-list-2 .room-content .room-info li i' => 'color: {{VALUE}}',
						],
					]
				);

				$this->add_responsive_control(
					'room_info_icon_margin',
					[
						'label' 		=> esc_html__( 'Margin', 'hotelft' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', '%', 'em' ],
						'selectors' 	=> [
							'{{WRAPPER}} .ova-room-list-2 .room-content .room-info li i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);

		$this->end_controls_section();
		
	}

    protected function hotelft_get_branch_product( $args ) {

        $args_query = [
            'post_type'         => 'product',
            'post_status'       => 'publish',
            'posts_per_page'    => $args['posts_per_page'],
            'orderby'           => $args['orderby'],
            'order'             => $args['order'],
            'fields'            => 'ids',
            'tax_query'         => [
                [
                    'taxonomy' => $args['taxonomy'],
                    'field'    => 'slug',
                    'terms'    => $args['branch'],
                    'operator' => 'IN',
                ],
            ],
        ];

        if ( 'all' != $args['category_slug'] ) {
            $category_args = [
                'taxonomy'  => 'product_cat',
                'field'     => 'slug',
                'terms'     => $args['category_slug'],
                'operator'  => 'IN',
            ];

            array_push( $args_query['tax_query'], $category_args );
        }

        $result  = new \WP_Query( $args_query );

        return $result;
    }

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();
		$value_taxonomy = 'taxonomy_'.$settings['taxonomy'];

		$args = [
			'posts_per_page' 	=> $settings['posts_per_page'],
			'orderby' 			=> $settings['orderby'],
			'order' 			=> $settings['order'],
			'category_slug'		=> $settings['categories'],
			'taxonomy'		    => $settings['taxonomy'],
			'branch'		    => $settings[$value_taxonomy],
		];

		$rooms =  $this->hotelft_get_branch_product( $args );

		 ?>
         
         <?php if ( $rooms->have_posts() ) : ?>
		 	<div class="ova-room-list-2">
				<?php while( $rooms->have_posts() ) : $rooms->the_post();
					$id 		= get_the_id();
					$title 		= get_the_title();
					$link 		= get_permalink( $id );
					$image_url 	= get_the_post_thumbnail_url( $id, 'single-post-thumbnail' );
					$image_id 	= get_post_thumbnail_id();
					$image_alt 	= '';

					if ( $image_id ) {
						$image_alt 		= get_post_meta( $image_id, '_wp_attachment_image_alt', true );
						if ( empty( $image_alt ) ) {
							$image_alt = get_the_title( $image_id );
						}
					}

					$price             = get_post_meta( $id, '_regular_price', true );
					$children_number   = get_post_meta( $id, 'ovabrw_children_number', true );
					$adult_number      = get_post_meta( $id, 'ovabrw_adult_number', true );
					$area_number       = get_post_meta( $id, 'ovabrw_acreage_number', true );
					$area_unit         = get_post_meta( $id, 'ovabrw_acreage_unit', true );

				?>

				<div class="room-content">
					
					<a class="room-image" href="<?php echo esc_url( $link ); ?>">
						<img src="<?php echo esc_url( $image_url ); ?>" alt="<?php echo esc_attr( $image_alt ); ?>">
					</a>

					<div class="room-meta">

						<div class="room-price-title">
							<h2 class="room-title">
								<a href="<?php echo esc_url( $link ); ?>">
									<?php echo esc_html( $title ); ?>
								</a>
							</h2>

							<span class="room-price">
		                    	<?php echo wc_price( $price ) . '/' . esc_html('night','hotelft');?>
		                    </span>
						</div>

						<ul class="room-info">
							<li>
								<i class="flaticon flaticon-manager"></i>
								<span>
								    <?php echo esc_html( $adult_number ) . ' ' . esc_html('Adults','hotelft');?>	
								</span>
							</li>
							<li>
								<i class="flaticon flaticon-adoption"></i>
								<span> 
									<?php echo esc_html( $children_number ) . ' ' . esc_html('Children','hotelft');?>	
								</span>
							</li>
							<li class="square">
								<i class="flaticon flaticon-select"></i>
								<span> 
									<?php echo esc_html( $area_number );?>	
									<?php echo esc_html( $area_unit );?><sup>2</sup>
								</span>
							</li>
						</ul>
					</div>
				</div>

				<?php endwhile; ?>
			</div>

        <?php else: ?>
		<div class="ova-rooms-not-found">
			<?php echo esc_html( 'Rooms not found', 'hotelft' ); ?>
		</div>
		<?php endif; wp_reset_postdata(); ?>
		 	
		<?php
	}

	
}
$widgets_manager->register( new Hotelft_Elementor_Room_List_2() );