<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Border;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Hotelft_Elementor_Room_List_Carousel extends Widget_Base {

	
	public function get_name() {
		return 'hotelft_elementor_room_list_carousel';
	}

	
	public function get_title() {
		return esc_html__( 'Room List Carousel', 'hotelft' );
	}

	
	public function get_icon() {
		return 'eicon-posts-carousel';
	}

	
	public function get_categories() {
		return [ 'hotelft' ];
	}

	public function get_script_depends() {
		// Carousel
		wp_enqueue_style( 'slick-carousel', get_template_directory_uri().'/assets/libs/slick/slick.css' );
		wp_enqueue_style( 'slick-carousel-theme', get_template_directory_uri().'/assets/libs/slick/slick-theme.css' );
		wp_enqueue_script( 'slick-carousel', get_template_directory_uri().'/assets/libs/slick/slick.min.js', array('jquery'), false, true );
		return [ 'hotelft-elementor-room-list-carousel' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'hotelft' ),
			]
		);	
			
			// Add Class control
			$args_query	= [
				'taxonomy' 	=> 'product_cat',
				'orderby' 	=> 'name',
	        	'order'   	=> 'ASC'
			];
            
            $categories            = get_categories($args_query);
            $default_category      = array( 'all' => esc_html__( 'All', 'hotelft' ) );
            $categories_data       = array();
            $result                = array();      

            if ( $categories && is_array( $categories ) ) {
				foreach ( $categories as $category ) {
					$categories_data[$category->slug] = $category->cat_name;
				}
			}

			$result = array_merge( $default_category, $categories_data );

			$this->add_control(
				'visibility',
				[
					'label' 	=> esc_html__( 'Room Visibility', 'hotelft' ),
					'type' 		=> Controls_Manager::SELECT,
					'default' 	=> 'featured',
					'options' 	=> [
						'featured' => esc_html__( 'Featured', 'hotelft' ),
						'public' 	=> esc_html__( 'Public', 'hotelft' ),
					],
				]
			);

			$this->add_control(
				'categories',
				[
					'label' 	=> esc_html__( 'Select Category', 'hotelft' ),
					'type' 		=> Controls_Manager::SELECT,
					'default' 	=> 'all',
					'options' 	=> $result,
				]
			);

			$this->add_control(
				'posts_per_page',
				[
					'label' 	=> esc_html__( 'Posts Per Page', 'hotelft' ),
					'type' 		=> Controls_Manager::NUMBER,
					'default' 	=> 4,
				]
			);

			$this->add_control(
				'orderby',
				[
					'label' 	=> esc_html__( 'Order By', 'hotelft' ),
					'type' 		=> Controls_Manager::SELECT,
					'default' 	=> 'title',
					'options' 	=> [
						'title' => esc_html__( 'Title', 'hotelft' ),
						'ID' 	=> esc_html__( 'ID', 'hotelft' ),
						'date' 	=> esc_html__( 'Date', 'hotelft' ),
					],
				]
			);

			$this->add_control(
				'order',
				[
					'label' 	=> esc_html__( 'Order', 'hotelft' ),
					'type' 		=> Controls_Manager::SELECT,
					'default' 	=> 'ASC',
					'options' 	=> [
						'ASC' 	=> esc_html__( 'Ascending', 'hotelft' ),
						'DESC' 	=> esc_html__( 'Descending', 'hotelft' ),
					],
				]
			);

		$this->end_controls_section();

		/*****************************************************************
						START SECTION ADDITIONAL
		******************************************************************/

		$this->start_controls_section(
			'section_additional_options',
			[
				'label' => esc_html__( 'Additional Options', 'hotelft' ),
			]
		);

			$this->add_control(
				'centerPadding',
				[
					'label'   => esc_html__( 'Center Padding', 'hotelft' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 0,
				]
				
			);

			$this->add_control(
				'infinite',
				[
					'label'   => esc_html__( 'Infinite Loop', 'hotelft' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'hotelft' ),
						'no'  => esc_html__( 'No', 'hotelft' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay',
				[
					'label'   => esc_html__( 'Autoplay', 'hotelft' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'hotelft' ),
						'no'  => esc_html__( 'No', 'hotelft' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay_speed',
				[
					'label'     => esc_html__( 'Autoplay Speed', 'hotelft' ),
					'type'      => Controls_Manager::NUMBER,
					'default'   => 3000,
					'step'      => 500,
					'condition' => [
						'autoplay' => 'yes',
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'dot_control',
				[
					'label'   => esc_html__( 'Show Dots', 'hotelft' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'hotelft' ),
						'no'  => esc_html__( 'No', 'hotelft' ),
					],
					'frontend_available' => true,
				]
			);

		$this->end_controls_section();

		/****************************  END SECTION ADDITIONAL *********************/

		$this->start_controls_section(
			'section_room_list_style',
			[
				'label' => esc_html__( 'Carousel Item', 'hotelft' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' 		=> 'room_border',
					'label' 	=> esc_html__( 'Border', 'hotelft' ),
					'selector' 	=> '{{WRAPPER}} .ova-room-list-carousel .room-content',
					'separator' => 'before',
				]
			);

			$this->add_responsive_control(
				'room_content_max_width',
				[
					'label' 	=> esc_html__( 'Max Width', 'hotelft' ),
					'type' 		=> Controls_Manager::SLIDER,
					'default' 	=> [
						'unit' 	=> 'px',
					],
					'tablet_default' => [
						'unit' => 'px',
					],
					'mobile_default' => [
						'unit' => 'px',
					],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
						'vw' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ 'px', '%', 'vw' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-room-list-carousel .room-content' => 'max-width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'room_border_radius',
				[
					'label' 		=> esc_html__( 'Border Radius', 'hotelft' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-room-list-carousel .room-content, {{WRAPPER}} .ova-room-list-carousel .room-content .mask, {{WRAPPER}} .ova-room-list-carousel .room-content img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'room_content_padding',
				[
					'label' 		=> esc_html__( 'Padding', 'hotelft' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-room-list-carousel .slick-slide' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

        // title room (product) style
		$this->start_controls_section(
			'section_room_title_style',
			[
				'label' => esc_html__( 'Room Title', 'hotelft' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'room_title_typography',
					'selector' 	=> '{{WRAPPER}} .ova-room-list-carousel .slick-slide .room-content .room-meta .room-title',
				]
			);

			$this->add_responsive_control(
				'room_title_padding',
				[
					'label' 		=> esc_html__( 'Padding', 'hotelft' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-room-list-carousel .slick-slide .room-content .room-meta .room-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'room_title_color_normal',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-room-list-carousel .slick-slide .room-content .room-meta .room-title a' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'room_title_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-room-list-carousel .slick-slide .room-content .room-meta .room-title:hover a' => 'color: {{VALUE}}',
					],
				]
			);

		$this->end_controls_section();

        // price style
		$this->start_controls_section(
			'section_room_price_style',
			[
				'label' => esc_html__( 'Room Price', 'hotelft' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'room_price_typography',
					'selector' 	=> '{{WRAPPER}} .ova-room-list-carousel .slick-slide .room-content .room-price',
				]
			);

			$this->add_control(
				'room_price_color',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-room-list-carousel .slick-slide .room-content .room-price' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'room_price_bgcolor',
				[
					'label' 	=> esc_html__( 'Background Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-room-list-carousel .slick-slide .room-content .room-price' => 'background-color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'room_price_padding',
				[
					'label' 		=> esc_html__( 'Padding', 'hotelft' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-room-list-carousel .slick-slide .room-content .room-price' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'room_price_border_radius',
				[
					'label' 		=> esc_html__( 'Border Radius', 'hotelft' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-room-list-carousel .slick-slide .room-content .room-price' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

        // room info crossbar
		$this->start_controls_section(
			'section_room_info_style',
			[
				'label' => esc_html__( 'Room Info', 'hotelft' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'room_info_typography',
					'selector' 	=> '{{WRAPPER}} .ova-room-list-carousel .slick-slide .room-content .room-info li',
				]
			);

			$this->add_control(
				'room_info_color',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-room-list-carousel .slick-slide .room-content .room-info li' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'room_info_bgcolor',
				[
					'label' 	=> esc_html__( 'Background Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-room-list-carousel .slick-slide .room-content .room-info' => 'background-color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'room_info_padding',
				[
					'label' 		=> esc_html__( 'Padding', 'hotelft' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-room-list-carousel .slick-slide .room-content .room-info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'room_info_border_radius',
				[
					'label' 		=> esc_html__( 'Border Radius', 'hotelft' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-room-list-carousel .slick-slide .room-content .room-info' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'room_info_icon',
				[
					'label' 	=> esc_html__( 'Icon', 'hotelft' ),
					'type' 		=> \Elementor\Controls_Manager::HEADING,
				]
			);

				$this->add_group_control(
					Group_Control_Typography::get_type(),
					[
						'name' 		=> 'room_info_icon_typography',
						'selector' 	=> '{{WRAPPER}} .ova-room-list-carousel .slick-slide .room-content .room-info li i',
					]
				);

				$this->add_control(
					'room_info_icon_color',
					[
						'label' 	=> esc_html__( 'Color', 'hotelft' ),
						'type' 		=> Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-room-list-carousel .slick-slide .room-content .room-info li i' => 'color: {{VALUE}}',
						],
					]
				);

				$this->add_responsive_control(
					'room_info_icon_margin',
					[
						'label' 		=> esc_html__( 'Margin', 'hotelft' ),
						'type' 			=> Controls_Manager::DIMENSIONS,
						'size_units' 	=> [ 'px', '%', 'em' ],
						'selectors' 	=> [
							'{{WRAPPER}} .ova-room-list-carousel .slick-slide .room-content .room-info li i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);

		$this->end_controls_section();

		/* Begin Dots Style */
		$this->start_controls_section(
            'dots_style',
            [
                'label' => esc_html__( 'Dots', 'hotelft' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
                'condition' => [
					'dot_control' => 'yes',
				]
            ]
        );

            $this->add_responsive_control(
				'dots_position_bottom',
				[
					'label' 	=> esc_html__( 'Bottom Position', 'hotelft' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => -200,
							'max' => 200,
						],
					],
					'size_units' 	=> [ 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-room-list-carousel .slick-dots' => 'bottom: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->start_controls_tabs( 'tabs_dots_style' );
				
				$this->start_controls_tab(
		            'tab_dots_normal',
		            [
		                'label' => esc_html__( 'Normal', 'hotelft' ),
		            ]
		        );

		            $this->add_control(
						'dot_color',
						[
							'label' 	=> esc_html__( 'Color', 'hotelft' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-room-list-carousel .slick-dots li button' => 'background-color: {{VALUE}}',
							],
						]
					);

					$this->add_responsive_control(
						'dots_width',
						[
							'label' 	=> esc_html__( 'Width', 'hotelft' ),
							'type' 		=> Controls_Manager::SLIDER,
							'range' => [
								'px' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'size_units' 	=> [ 'px' ],
							'selectors' 	=> [
								'{{WRAPPER}} .ova-room-list-carousel .slick-dots li button' => 'width: {{SIZE}}{{UNIT}};',
							],
						]
					);

					$this->add_responsive_control(
						'dots_height',
						[
							'label' 	=> esc_html__( 'Height', 'hotelft' ),
							'type' 		=> Controls_Manager::SLIDER,
							'range' => [
								'px' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'size_units' 	=> [ 'px' ],
							'selectors' 	=> [
								'{{WRAPPER}} .ova-room-list-carousel .slick-dots li button' => 'height: {{SIZE}}{{UNIT}};',
							],
						]
					);

					$this->add_control(
			            'dots_border_radius',
			            [
			                'label' 		=> esc_html__( 'Border Radius', 'hotelft' ),
			                'type' 			=> Controls_Manager::DIMENSIONS,
			                'size_units' 	=> [ 'px', '%' ],
			                'selectors' 	=> [
			                    '{{WRAPPER}} .ova-room-list-carousel .slick-dots li button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			                ],
			            ]
			        );

		        $this->end_controls_tab();

		        $this->start_controls_tab(
		            'tab_dots_active',
		            [
		                'label' => esc_html__( 'Active', 'hotelft' ),
		            ]
		        );

		             $this->add_control(
						'dot_color_active',
						[
							'label' 	=> esc_html__( 'Color', 'hotelft' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-room-list-carousel .slick-dots li.slick-active button' => 'background-color: {{VALUE}}',
							],
						]
					);

					$this->add_responsive_control(
						'dots_width_active',
						[
							'label' 	=> esc_html__( 'Width', 'hotelft' ),
							'type' 		=> Controls_Manager::SLIDER,
							'range' => [
								'px' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'size_units' 	=> [ 'px' ],
							'selectors' 	=> [
								'{{WRAPPER}} .ova-room-list-carousel .slick-dots li.slick-active button' => 'width: {{SIZE}}{{UNIT}};',
							],
						]
					);

					$this->add_responsive_control(
						'dots_height_active',
						[
							'label' 	=> esc_html__( 'Height', 'hotelft' ),
							'type' 		=> Controls_Manager::SLIDER,
							'range' => [
								'px' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'size_units' 	=> [ 'px' ],
							'selectors' 	=> [
								'{{WRAPPER}} .ova-room-list-carousel .slick-dots li.slick-active button' => 'height: {{SIZE}}{{UNIT}};',
							],
						]
					);

					$this->add_control(
			            'dots_border_radius_active',
			            [
			                'label' 		=> esc_html__( 'Border Radius', 'hotelft' ),
			                'type' 			=> Controls_Manager::DIMENSIONS,
			                'size_units' 	=> [ 'px', '%' ],
			                'selectors' 	=> [
			                    '{{WRAPPER}} .ova-room-list-carousel .slick-dots li.slick-active button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			                ],
			            ]
			        );

		        $this->end_controls_tab();
			$this->end_controls_tabs();

        $this->end_controls_section();
        /* End Dots Style */
		
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

		$args = [
			'posts_per_page' 	=> $settings['posts_per_page'],
			'orderby' 			=> $settings['orderby'],
			'order' 			=> $settings['order'],
			'category_slug'		=> $settings['categories'],
		];

		if ( $settings['visibility'] === 'featured' ) {
            $rooms =  hotelft_get_featured_product( $args );
		}
		else {
			$rooms =  hotelft_get_product( $args );
		}

		// carousel data option
		$data_options['centerPadding']      = $settings['centerPadding'];
		$data_options['loop']               = $settings['infinite'] === 'yes' ? true : false;
		$data_options['autoplay']           = $settings['autoplay'] === 'yes' ? true : false;
		$data_options['autoplay_speed']     = $settings['autoplay_speed'];
		$data_options['dots']               = $settings['dot_control'] === 'yes' ? true : false;
		$data_options['rtl']				= is_rtl() ? true: false;
        

		 ?>

	     <?php if ( $rooms->have_posts() ) : 
	     	$i = 0;
	     ?>
            <div class="ova-room-list-carousel">

				<div class="room-list-carousel" data-options="<?php echo esc_attr(json_encode($data_options)) ?>">
					<?php while( $rooms->have_posts() ) : $rooms->the_post();
						$id 		= get_the_id();
						$title 		= get_the_title();
						$link 		= get_permalink( $id );
					
						$image_id 	= get_post_thumbnail_id();
						$image_url  = wp_get_attachment_image_url( $image_id , 'hotelft_room_carousel' );
						$image_alt 	= '';

						if ( $image_id ) {
							$image_alt 		= get_post_meta( $image_id, '_wp_attachment_image_alt', true );
							if ( empty( $image_alt ) ) {
								$image_alt = get_the_title( $image_id );
							}
						}

						$price             = get_post_meta( $id, '_regular_price', true );
						$children_number   = get_post_meta( $id, 'ovabrw_children_number', true );
						$adult_number      = get_post_meta( $id, 'ovabrw_adult_number', true );
						$area_number       = get_post_meta( $id, 'ovabrw_acreage_number', true );
						$area_unit         = get_post_meta( $id, 'ovabrw_acreage_unit', true );

					?>

	                    <div class="item room-content">
							
							<a class="room-image" href="<?php echo esc_url( $link ); ?>">
								<div class="mask"></div>
								<img src="<?php echo esc_url( $image_url ); ?>" alt="<?php echo esc_attr( $image_alt ); ?>">
							</a>

		                    <span class="room-price">
		                    	<?php echo wc_price( $price ) . ' ' . '/' . esc_html('night','hotelft');?>
		                    </span>

							<div class="room-meta">

								<h2 class="room-title">
									<a href="<?php echo esc_url( $link ); ?>">
										<?php echo esc_html( $title ); ?>
									</a>
								</h2>

								<ul class="room-info">
									<li>
										<i class="flaticon flaticon-manager"></i>
										<span>
										    <?php echo esc_html( $adult_number ) . ' ' . esc_html('Adults','hotelft');?>	
										</span>
									</li>
									<li>
										<i class="flaticon flaticon-adoption"></i>
										<span> 
											<?php echo esc_html( $children_number ) . ' ' . esc_html('Children','hotelft');?>	
										</span>
									</li>
									<li class="square">
										<i class="flaticon flaticon-select"></i>
										<span>
											<?php echo esc_html( $area_number );?>	
									        <?php echo esc_html( $area_unit );?><sup>2</sup>
										</span>
									</li>
								</ul>
							</div>
						</div>

					<?php $i++; endwhile; ?>

				</div>

			</div>

	    <?php else: ?>
		<div class="ova-rooms-not-found">
			<?php echo esc_html( 'Rooms not found', 'hotelft' ); ?>
		</div>
		<?php endif; wp_reset_postdata(); ?>
		 	
		<?php
	}

	
}
$widgets_manager->register( new Hotelft_Elementor_Room_List_Carousel() );