<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Border;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Hotelft_Elementor_Service_Info extends Widget_Base {

	
	public function get_name() {
		return 'hotelft_elementor_service_info';
	}

	
	public function get_title() {
		return esc_html__( 'Service Info', 'hotelft' );
	}

	
	public function get_icon() {
		return 'eicon-info';
	}

	
	public function get_categories() {
		return [ 'hotelft' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'hotelft' ),
			]
		);	
			
			
			// Add Class control

			$this->add_control(
				'icon',
				[
					'label' => __( 'Icon', 'hotelft' ),
					'type' => Controls_Manager::ICONS,
					'default' => [
						'value' => 'icomoon icomoon-diamond',
						'library' => 'icomoon',
					],

				]
			);
            
			$this->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'hotelft' ),
					'type' => Controls_Manager::TEXT,
					'row' => 5,
					'default' => esc_html__('Top restaurants','hotelft'),
				]
			);

			$this->add_control(
				'description',
				[
					'label' 	=> esc_html__( 'Description', 'hotelft' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__("Our restaurant on the top floor offers dishes that celebrate the flavors of all the country's regions, from north to south in a cozy sitting with warm light.", 'hotelft' ),
				]
			);

			$this->add_control(
				'link_button',
				[
					'label' => esc_html__( 'Link Button', 'hotelft' ),
					'type' => Controls_Manager::URL,
					
					'dynamic' => [
						'active' => true,
					],
					'placeholder' => esc_html__( 'https://your-link.com', 'hotelft' ),
				]
			);

			$this->add_control(
				'text_button',
				[
					'label' => esc_html__( 'Text Button', 'hotelft' ),
					'type' => Controls_Manager::TEXT,
					'row' => 5,
					'default' => esc_html__('View details','hotelft'),
				]
			);

			$this->add_responsive_control(
				'align',
				[
					'label' => esc_html__( 'Alignment', 'hotelft' ),
					'type' => Controls_Manager::CHOOSE,
					'options' => [
						'left' => [
							'title' => esc_html__( 'Left', 'hotelft' ),
							'icon' => 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'hotelft' ),
							'icon' => 'eicon-text-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'hotelft' ),
							'icon' => 'eicon-text-align-right',
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-service-info' => 'text-align: {{VALUE}};',
					],
					'separator' => 'before'
				]
			);


		$this->end_controls_section();

		/* Begin Top Style */
		$this->start_controls_section(
            'card_style',
            [
                'label' => esc_html__( 'Top Info', 'hotelft' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

			$this->add_responsive_control(
				'top_align',
				[
					'label' => esc_html__( 'Alignment', 'hotelft' ),
					'type' => Controls_Manager::CHOOSE,
					'options' => [
						'flex-start' => [
							'title' => esc_html__( 'Left', 'hotelft' ),
							'icon' => 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'hotelft' ),
							'icon' => 'eicon-text-align-center',
						],
						'flex-end' => [
							'title' => esc_html__( 'Right', 'hotelft' ),
							'icon' => 'eicon-text-align-right',
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-service-info .top' => 'justify-content: {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
	            'top_row_reverse',
	            [
	                'label' 	=> esc_html__( 'Row Reverse', 'hotelft' ),
	                'type' 		=> \Elementor\Controls_Manager::CHOOSE,
	                'options' 	=> [
	                    'row-reverse' => [
	                        'title' => esc_html__( 'Reverse', 'hotelft' ),
	                        'icon' 	=> 'eicon-grow',
	                    ],
	                ],
	                'selectors' => [
	                    '{{WRAPPER}} .ova-service-info .top' => 'flex-direction: {{VALUE}}',
	                ],
	            ]
	        );

			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' 		=> 'top_border',
					'label' 	=> esc_html__( 'Border', 'hotelft' ),
					'selector' 	=> '{{WRAPPER}} .ova-service-info .top',
				]
			);

			$this->add_responsive_control(
	            'top_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-service-info .top' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
	            'top_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-service-info .top' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End service info style */

		/* Begin icon Style */
		$this->start_controls_section(
            'icon_style',
            [
                'label' => esc_html__( 'Icon', 'hotelft' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );
            
			$this->add_responsive_control(
				'size_icon',
				[
					'label' 		=> esc_html__( 'Size', 'hotelft' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px'],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-service-info .top i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'icon_color',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-info .top i' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'icon_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-info:hover .top i' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
	            'icon_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-service-info .top i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	                'description'   => esc_html__( 'Icons vs title Space between', 'hotelft' ),
	            ]
	        );

        $this->end_controls_section();
		/* End icon style */

		/* Begin title Style */
		$this->start_controls_section(
            'title_style',
            [
                'label' => esc_html__( 'Title', 'hotelft' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'title_typography',
					'selector' 	=> '{{WRAPPER}} .ova-service-info .top .title',
				]
			);

			$this->add_control(
				'title_color',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-info .top .title' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'title_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-info:hover .top .title' => 'color: {{VALUE}};',
					],
				]
			);

        $this->end_controls_section();
		/* End title style */

		/* Begin description Style */
		$this->start_controls_section(
            'description_style',
            [
                'label' => esc_html__( 'Description', 'hotelft' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'description_typography',
					'selector' 	=> '{{WRAPPER}} .ova-service-info .description',
				]
			);

			$this->add_control(
				'description_color',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-info .description' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
	            'description_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-service-info .description' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End description style */

		/* Begin button Style */
		$this->start_controls_section(
            'button_style',
            [
                'label' => esc_html__( 'Button', 'hotelft' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'text_button_typography',
					'selector' 	=> '{{WRAPPER}} .ova-service-info .button',
				]
			);

			$this->add_control(
				'button_color',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-info .button' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'button_bgcolor',
				[
					'label' 	=> esc_html__( 'Background Color', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-info .button' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'button_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-info .button:hover' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'button_bgcolor_hover',
				[
					'label' 	=> esc_html__( 'Background Color Hover', 'hotelft' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-service-info .button:hover' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' 		=> 'button_border',
					'label' 	=> esc_html__( 'Border', 'hotelft' ),
					'selector' 	=> '{{WRAPPER}} .ova-service-info .button',
				]
			);

			$this->add_responsive_control(
	            'button_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-service-info .button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
	            'button_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'hotelft' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-service-info .button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_control(
				'icon_button_heading',
				[
					'label' 	=> esc_html__( 'Icon Button', 'hotelft' ),
					'type' 		=> Controls_Manager::HEADING,
					'separator' => 'before'
				]
			);

	        $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'icon_button_typography',
					'selector' 	=> '{{WRAPPER}} .ova-service-info .button i',
				]
			);

        $this->end_controls_section();
		/* End button style */
		
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

		$title            =    $settings['title'];
		$description      =    $settings['description'];
		$text_button      =    $settings['text_button'];
		$class_icon       =    $settings['icon']['value'];

		// get link 
		$link_button             = $settings['link_button']['url'];
		$link_button_is_external = $settings['link_button']['is_external'];
		$link_button_target      = ( $link_button_is_external == 'on' ) ? 'target="_blank"' : '';

		 ?>
             
            <?php if(!empty( $link['url'])) : ?>
			<?php $nofollow = ( isset( $link['nofollow'] ) && $link['nofollow'] ) ? ' rel="nofollow"' : ''; ?>
			  <a href="<?php echo esc_url( $link['url'] ); ?> " <?php echo ( isset( $link['is_external'] ) && $link['is_external'] !== '' ) ? ' target="_blank"' : '' ?>  <?php echo esc_attr( $nofollow ); ?>>
		    <?php endif; ?>
 
	            <div class="ova-service-info">

	            	<div class="top">
	            		<?php if (!empty( $class_icon )): ?>
			            	<i class="<?php echo esc_attr( $class_icon ); ?>"></i>
			            <?php endif;?>

			            <?php if (!empty( $title )): ?>
							<h3 class="title">
								<?php echo esc_html( $title ); ?>
							</h3>
						<?php endif;?>
	            	</div>

					<?php if (!empty( $description )): ?>
						<p class="description">
							<?php echo esc_html( $description ); ?>
						</p>
					<?php endif;?>

					<?php if (!empty( $text_button )): ?>
						<?php if( $link_button ){ ?>
							<a href="<?php echo esc_url( $link_button );?>" <?php printf( $link_button_target ); ?>>
						<?php } ?>
						<div class="button">
							<?php echo esc_html( $text_button ); ?>
							<i class="ovaicon ovaicon-right-arrow"></i>
						</div>
						<?php if( $link_button ){ ?>
							</a>
						<?php } ?>
					<?php endif;?>
				
					
			    </div>

		   <?php if(!empty( $link['url'])) : ?>
			 </a>
		   <?php endif; ?>
		 	
		<?php
	}

	
}
$widgets_manager->register( new Hotelft_Elementor_Service_Info() );