<?php

class Hotelft_Elementor {
	
	function __construct() {
            
		// Register Header Footer Category in Pane
	    add_action( 'elementor/elements/categories_registered', array( $this, 'hotelft_add_category' ) );

	    add_action( 'elementor/frontend/after_register_scripts', array( $this, 'hotelft_enqueue_scripts' ) );
		
		add_action( 'elementor/widgets/register', array( $this, 'hotelft_include_widgets' ) );
		
		add_filter( 'elementor/controls/animations/additional_animations', array( $this, 'hotelft_add_animations'), 10 , 0 );

		add_action( 'wp_print_footer_scripts', array( $this, 'hotelft_enqueue_footer_scripts' ) );

		add_action( 'elementor/element/button/section_style/before_section_start', array( $this, 'hotelft_button_custom' ), 10, 2 );

		// load icons
		add_filter( 'elementor/icons_manager/additional_tabs', array( $this, 'hotelft_icons_filters_new' ), 9999999, 1 );

	}

	
	function hotelft_add_category(  ) {

	    \Elementor\Plugin::instance()->elements_manager->add_category(
	        'hf',
	        [
	            'title' => __( 'Header Footer', 'hotelft' ),
	            'icon' => 'fa fa-plug',
	        ]
	    );

	    \Elementor\Plugin::instance()->elements_manager->add_category(
	        'hotelft',
	        [
	            'title' => __( 'Hotelft', 'hotelft' ),
	            'icon' => 'fa fa-plug',
	        ]
	    );

	}

	function hotelft_enqueue_scripts(){
        
        $files = glob(get_theme_file_path('/assets/js/elementor/*.js'));
        
        foreach ($files as $file) {
            $file_name = wp_basename($file);
            $handle    = str_replace(".js", '', $file_name);
            $src       = get_theme_file_uri('/assets/js/elementor/' . $file_name);
            if (file_exists($file)) {
                wp_register_script( 'hotelft-elementor-' . $handle, $src, ['jquery'], false, true );
            }
        }


	}

	function hotelft_include_widgets( $widgets_manager ) {
        $files = glob(get_theme_file_path('elementor/widgets/*.php'));
        foreach ($files as $file) {
            $file = get_theme_file_path('elementor/widgets/' . wp_basename($file));
            if (file_exists($file)) {
                require_once $file;
            }
        }
    }

    function hotelft_add_animations(){
    	$animations = array(
            'Hotelft' => array(
                'ova-move-up' 		=> esc_html__('Move Up', 'hotelft'),
                'ova-move-down' 	=> esc_html__( 'Move Down', 'hotelft' ),
                'ova-move-left'     => esc_html__('Move Left', 'hotelft'),
                'ova-move-right'    => esc_html__('Move Right', 'hotelft'),
                'ova-scale-up'      => esc_html__('Scale Up', 'hotelft'),
                'ova-flip'          => esc_html__('Flip', 'hotelft'),
                'ova-helix'         => esc_html__('Helix', 'hotelft'),
                'ova-popup'			=> esc_html__( 'PopUp','hotelft' )
            ),
        );

        return $animations;
    }

   

	function hotelft_enqueue_footer_scripts(){
		 // Font Icon
	    wp_enqueue_style('ovaicon', HOTELFT_URI.'/assets/libs/ovaicon/font/ovaicon.css', array(), null);
	    wp_enqueue_style('iconly', HOTELFT_URI.'/assets/libs/iconly/css/style.css', array(), null);
	    wp_enqueue_style('icomoon', HOTELFT_URI.'/assets/libs/icomoon/style.css', array(), null);
	    wp_enqueue_style('flaticon', HOTELFT_URI.'/assets/libs/flaticon/font/flaticon.css', array(), null);
	}

	// Ova button custom 
    function hotelft_button_custom( $element, $args ) {
		/** @var \Elementor\Element_Base $element */
		$element->start_controls_section(
			'ova_tabs',
			[
				'tab' 	=> \Elementor\Controls_Manager::TAB_STYLE,
				'label' => esc_html__( 'Ova Button', 'hotelft' ),
			]
		); 

		    $element->add_control(
				'icon_button_heading',
				[
					'label' => esc_html__( 'Icon', 'hotelft' ),
					'type' => \Elementor\Controls_Manager::HEADING,
				]
			);

		    $element->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'icon_button_typography',
					'selector' 	=> '{{WRAPPER}} .elementor-button-icon i',
				]
			);

			$element->add_control(
				'icon_button_color',
				[
					'label' 	=> esc_html__( 'Color', 'hotelft' ),
					'type' 		=> \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .elementor-button-icon i' => 'color : {{VALUE}};'
					],
				]
			);

			$element->add_control(
				'icon_button_color_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'hotelft' ),
					'type' 		=> \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .elementor-button-icon:hover i' => 'color : {{VALUE}};'
					],
				]
			);

			$element->add_responsive_control(
		        'icon_button_padding',
		        [
		            'label' 		=> esc_html__( 'Padding', 'hotelft' ),
		            'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
		            'size_units' 	=> [ 'px', '%', 'em' ],
		            'selectors' 	=> [
		             '{{WRAPPER}} .elementor-button-icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		            ],
		         ]
		    );

		    $element->add_control(
				'text_button_heading',
				[
					'label' => esc_html__( 'Text', 'hotelft' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before'
				]
			);

			$element->add_responsive_control(
		        'text_button_padding',
		        [
		            'label' 		=> esc_html__( 'Padding', 'hotelft' ),
		            'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
		            'size_units' 	=> [ 'px', '%', 'em' ],
		            'selectors' 	=> [
		             '{{WRAPPER}} .elementor-button-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		            ],
		         ]
		    );

		$element->end_controls_section();
	}
	
	
	public function hotelft_icons_filters_new( $tabs = array() ) {

		$newicons = [];
		$font_data['json_url'] = HOTELFT_URI.'/assets/libs/ovaicon/ovaicon.json';
		$font_data['name'] = 'ovaicon';

		$newicons[ $font_data['name'] ] = [
			'name'          => $font_data['name'],
			'label'         => esc_html__( 'Default', 'hotelft' ),
			'url'           => '',
			'enqueue'       => '',
			'prefix'        => 'ovaicon-',
			'displayPrefix' => '',
			'ver'           => '1.0',
			'fetchJson'     => $font_data['json_url'],
			
		];

		// Add Iconly
		$iconly['json_url'] = HOTELFT_URI.'/assets/libs/iconly/iconly.json';
		$iconly['name'] = 'iconly';

		$newicons[ $iconly['name'] ] = [
			'name'          => $iconly['name'],
			'label'         => esc_html__( 'Iconly', 'hotelft' ),
			'url'           => '',
			'enqueue'       => '',
			'prefix'        => 'iconly-',
			'displayPrefix' => '',
			'ver'           => '1.0',
			'fetchJson'     => $iconly['json_url'],
			
		];

		// Add Iconmoon
		$iconmoon['json_url'] = HOTELFT_URI.'/assets/libs/icomoon/icomoon.json';
		$iconmoon['name'] = 'icomoon';

		$newicons[ $iconmoon['name'] ] = [
			'name'          => $iconmoon['name'],
			'label'         => esc_html__( 'Icomoon', 'hotelft' ),
			'url'           => '',
			'enqueue'       => '',
			'prefix'        => 'icomoon-',
			'displayPrefix' => '',
			'ver'           => '1.0',
			'fetchJson'     => $iconmoon['json_url'],
			
		];

		// Add Flaticon
		$flaticon['json_url'] = HOTELFT_URI.'/assets/libs/flaticon/flaticon.json';
		$flaticon['name'] = 'flaticon';

		$newicons[ $flaticon['name'] ] = [
			'name'          => $flaticon['name'],
			'label'         => esc_html__( 'Flaticon', 'hotelft' ),
			'url'           => '',
			'enqueue'       => '',
			'prefix'        => 'flaticon-',
			'displayPrefix' => '',
			'ver'           => '1.0',
			'fetchJson'     => $flaticon['json_url'],
		];


		return array_merge( $tabs, $newicons );

	}
    

}

return new Hotelft_Elementor();





